close()
Explicitly close the module-level browser and CDP connection.
Usage
close()Call this when you’re done taking screenshots to clean up Chrome processes. If not called, cleanup happens automatically at interpreter exit.
Explicitly close the module-level browser and CDP connection.
Usage
Call this when you’re done taking screenshots to clean up Chrome processes. If not called, cleanup happens automatically at interpreter exit.